## 3.15.0.6 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 3.15.0.5 (2022-11-23)

Mark first argument of `__[get|set|del]attr__` as `str` (#9245)

## 3.15.0.4 (2022-11-13)

Make peewee stubs compatible with peewee 3.15.4 (#9176)

## 3.15.0.3 (2022-11-09)

All `__nonzero__` are methods that return `bool` (#9139)

## 3.15.0.2 (2022-11-09)

Annotate known magic-method return types (#9131)

## 3.15.0.1 (2022-11-08)

Fix and allow classes with missing metaclasses (#9136)

## 3.15.0.0 (2022-10-04)

Add auto-generated peewee stubs (#8834)

